If you would like to contribute to the development of OpenStack, you should
follow the steps in this page:

   http://docs.openstack.org/infra/manual/developers.html

If you already knew how the OpenStack CI system works and your
OpenStack accounts is setup properly, you can start from the development
workflow section in that documentation to know how you should commit your
patch set for review via the Gerrit tool:

   http://docs.openstack.org/infra/manual/developers.html#development-workflow

Any pull requests submitted through GitHub will be ignored.

Any bug should be filed on Launchpad, not GitHub:

   https://bugs.launchpad.net/tricircle
